@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2019 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2019 - 2022 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -524,13 +524,11 @@ class MicroPythonWidget(QWidget, Ui_MicroPythonWidget):
         @type QPoint
         """
         if Globals.isMacPlatform():
-            copyKeys = QKeySequence(Qt.Modifier.CTRL + Qt.Key.Key_C)
-            pasteKeys = QKeySequence(Qt.Modifier.CTRL + Qt.Key.Key_V)
+            copyKeys = QKeySequence("Ctrl+C")
+            pasteKeys = QKeySequence("Ctrl+V")
         else:
-            copyKeys = QKeySequence(
-                Qt.Modifier.CTRL + Qt.Modifier.SHIFT + Qt.Key.Key_C)
-            pasteKeys = QKeySequence(
-                Qt.Modifier.CTRL + Qt.Modifier.SHIFT + Qt.Key.Key_V)
+            copyKeys = QKeySequence("Ctrl+Shift+C")
+            pasteKeys = QKeySequence("Ctrl+Shift+V")
         menu = QMenu(self)
         menu.addAction(self.tr("Clear"), self.__clear)
         menu.addSeparator()
