@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2021 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2021 - 2022 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -15,6 +15,7 @@ from PyQt6.QtCore import pyqtSlot, Qt, QCoreApplication, QThread, QEventLoop
 from PyQt6.QtWidgets import QDialog
 
 from EricWidgets.EricPathPicker import EricPathPickerModes
+from EricWidgets.EricApplication import ericApp
 
 from .Ui_UF2FlashDialog import Ui_UF2FlashDialog
 
@@ -571,7 +572,9 @@ class UF2FlashDialog(QDialog, Ui_UF2FlashDialog):
         self.bootPicker.setEnabled(False)
         
         self.__mandatoryStyleSheet = (
-            "QLineEdit {border: 2px solid;border-color: #800000}"
+            "QLineEdit {border: 2px solid; border-color: #dd8888}"
+            if ericApp().usesDarkPalette() else
+            "QLineEdit {border: 2px solid; border-color: #800000}"
         )
         self.__manualType = "<manual>"
         
