@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2011 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2011 - 2022 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -29,6 +29,7 @@ import Preferences
 import Utilities
 
 from . import pycodestyle
+from . import CodeStyleCheckerUtilities
 
 from .Miscellaneous.MiscellaneousDefaults import (
     MiscellaneousCheckerDefaultArgs
@@ -76,6 +77,9 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
         "E": QCoreApplication.translate(
             "CheckerCategories",
             "Errors"),
+        "I": QCoreApplication.translate(
+            "CheckerCategories",
+            "Imports"),
         "M": QCoreApplication.translate(
             "CheckerCategories",
             "Miscellaneous"),
@@ -300,30 +304,10 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
                 result["display"]
             ]
         )
-        if msgCode.startswith(("W", "-", "C", "M")):
-            itm.setIcon(1, UI.PixmapCache.getIcon("warning"))
-        elif msgCode.startswith(("A", "N")):
-            itm.setIcon(1, UI.PixmapCache.getIcon("namingError"))
-        elif msgCode.startswith("D"):
-            itm.setIcon(1, UI.PixmapCache.getIcon("docstringError"))
-        elif msgCode.startswith("P"):
-            itm.setIcon(1, UI.PixmapCache.getIcon("dirClosed"))
-        elif msgCode.startswith("Y"):
-            itm.setIcon(1, UI.PixmapCache.getIcon("filePython"))
-        elif msgCode.startswith("S"):
-            if "severity" in result:
-                if result["severity"] == "H":
-                    itm.setIcon(1, UI.PixmapCache.getIcon("securityLow"))
-                elif result["severity"] == "M":
-                    itm.setIcon(1, UI.PixmapCache.getIcon("securityMedium"))
-                elif result["severity"] == "L":
-                    itm.setIcon(1, UI.PixmapCache.getIcon("securityHigh"))
-                else:
-                    itm.setIcon(1, UI.PixmapCache.getIcon("securityLow"))
-            else:
-                itm.setIcon(1, UI.PixmapCache.getIcon("securityLow"))
-        else:
-            itm.setIcon(1, UI.PixmapCache.getIcon("syntaxError"))
+        
+        CodeStyleCheckerUtilities.setItemIcon(
+            itm, 1, msgCode, result.get("severity"))
+        
         if result["fixed"]:
             itm.setIcon(0, UI.PixmapCache.getIcon("issueFixed"))
         elif (
@@ -421,6 +405,35 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
         self.__statistics["_IssuesFixed"] = 0
         self.__statistics["_SecurityOK"] = 0
     
+    def __getBanRelativeImportsValue(self):
+        """
+        Private method to get the value corresponding the selected button.
+        
+        @return value for the BanRelativeImports argument
+        @rtype str
+        """
+        if self.banParentsButton.isChecked():
+            return "parents"
+        elif self.banAllButton.isChecked():
+            return "true"
+        else:
+            return ""
+    
+    def __setBanRelativeImports(self, value):
+        """
+        Private method to set the button according to the ban relative imports
+        setting.
+        
+        @param value value of the ban relative imports setting
+        @type str
+        """
+        if value == "parents":
+            self.banParentsButton.setChecked(True)
+        elif value == "true":
+            self.banAllButton.setChecked(True)
+        else:
+            self.allowAllButton.setChecked(True)
+    
     def prepare(self, fileList, project):
         """
         Public method to prepare the dialog with a list of filenames.
@@ -562,6 +575,13 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
                     SecurityDefaults["check_typed_exception"],
             }
         
+        if "ImportsChecker" not in self.__data:
+            self.__data["ImportsChecker"] = {
+                "ApplicationPackageNames": [],
+                "BannedModules": [],
+                "BanRelativeImports": "",
+            }
+        
         self.__initCategoriesList(self.__data["EnabledCheckerCategories"])
         self.excludeFilesEdit.setText(self.__data["ExcludeFiles"])
         self.excludeMessagesEdit.setText(self.__data["ExcludeMessages"])
@@ -823,11 +843,19 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
                     self.typedExceptionsCheckBox.isChecked(),
             }
             
+            importsArgs = {
+                "ApplicationPackageNames":
+                    sorted(self.appPackagesEdit.toPlainText().split()),
+                "BannedModules":
+                    sorted(self.bannedModulesEdit.toPlainText().split()),
+                "BanRelativeImports": self.__getBanRelativeImportsValue(),
+            }
+            
             self.__options = [excludeMessages, includeMessages, repeatMessages,
                               fixCodes, noFixCodes, fixIssues, maxLineLength,
                               maxDocLineLength, blankLines, hangClosing,
                               docType, codeComplexityArgs, miscellaneousArgs,
-                              annotationArgs, securityArgs]
+                              annotationArgs, securityArgs, importsArgs]
             
             # now go through all the files
             self.progress = 0
@@ -1255,6 +1283,13 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
                     "CheckTypedException":
                         self.typedExceptionsCheckBox.isChecked(),
                 },
+                "ImportsChecker": {
+                    "ApplicationPackageNames":
+                        sorted(self.appPackagesEdit.toPlainText().split()),
+                    "BannedModules":
+                        sorted(self.bannedModulesEdit.toPlainText().split()),
+                    "BanRelativeImports": self.__getBanRelativeImportsValue(),
+                },
             }
             if (
                 json.dumps(data, sort_keys=True) !=
@@ -1512,7 +1547,7 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
             )
         ))
         
-        # type annotations
+        # Type Annotations Checker
         self.minAnnotationsCoverageSpinBox.setValue(int(
             Preferences.getSettings().value(
                 "PEP8/MinimumAnnotationsCoverage",
@@ -1554,7 +1589,7 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
                 "PEP8/OverloadDecorators",
                 AnnotationsCheckerDefaultArgs["OverloadDecorators"]))))
         
-        # security
+        # Security Checker
         from .Security.SecurityDefaults import SecurityDefaults
         self.tmpDirectoriesEdit.setPlainText("\n".join(
             Preferences.toList(Preferences.getSettings().value(
@@ -1597,6 +1632,17 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
                 "PEP8/CheckTypedException",
                 SecurityDefaults["check_typed_exception"]))),
         
+        # Imports Checker
+        self.appPackagesEdit.setPlainText(" ".join(
+            sorted(Preferences.toList(Preferences.getSettings().value(
+                "PEP8/ApplicationPackageNames", [])))))
+        self.bannedModulesEdit.setPlainText(" ".join(
+            sorted(Preferences.toList(Preferences.getSettings().value(
+                "PEP8/BannedModules", [])))))
+        self.__setBanRelativeImports(
+            Preferences.getSettings().value(
+                "PEP8/BanRelativeImports", ""))
+        
         self.__cleanupData()
     
     @pyqtSlot()
@@ -1661,7 +1707,7 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
             "PEP8/CommentedCodeWhitelist",
             self.__getCommentedCodeCheckerWhiteList())
         
-        # type annotations
+        # Type Annotations Checker
         Preferences.getSettings().setValue(
             "PEP8/MinimumAnnotationsCoverage",
             self.minAnnotationsCoverageSpinBox.value())
@@ -1695,7 +1741,7 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
             [d.strip()
              for d in self.overloadDecoratorEdit.text().split(",")])
         
-        # security
+        # Security Checker
         Preferences.getSettings().setValue(
             "PEP8/HardcodedTmpDirectories",
             [t.strip()
@@ -1732,6 +1778,17 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
         Preferences.getSettings().setValue(
             "PEP8/CheckTypedException",
             self.typedExceptionsCheckBox.isChecked()),
+        
+        # Imports Checker
+        Preferences.getSettings().setValue(
+            "PEP8/ApplicationPackageNames",
+            sorted(self.appPackagesEdit.toPlainText().split()))
+        Preferences.getSettings().setValue(
+            "PEP8/BannedModules",
+            sorted(self.bannedModulesEdit.toPlainText().split()))
+        Preferences.getSettings().setValue(
+            "PEP8/BanRelativeImports",
+            self.__getBanRelativeImportsValue())
     
     @pyqtSlot()
     def on_resetDefaultButton_clicked(self):
@@ -1792,7 +1849,7 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
                 "CommentedCodeChecker"]["WhiteList"]
         )
         
-        # type annotations
+        # Type Annotations Checker
         Preferences.getSettings().setValue(
             "PEP8/MinimumAnnotationsCoverage",
             AnnotationsCheckerDefaultArgs["MinimumCoverage"])
@@ -1824,7 +1881,7 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
             "PEP8/OverloadDecorators",
             AnnotationsCheckerDefaultArgs["OverloadDecorators"])
         
-        # security
+        # Security Checker
         from .Security.SecurityDefaults import SecurityDefaults
         Preferences.getSettings().setValue(
             "PEP8/HardcodedTmpDirectories",
@@ -1857,6 +1914,14 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
             "PEP8/CheckTypedException",
             SecurityDefaults["check_typed_exception"])
         
+        # Imports Checker
+        Preferences.getSettings().setValue(
+            "PEP8/ApplicationPackageNames", [])
+        Preferences.getSettings().setValue(
+            "PEP8/BannedModules", [])
+        Preferences.getSettings().setValue(
+            "PEP8/BanRelativeImports", "")
+        
         # Update UI with default values
         self.on_loadDefaultButton_clicked()
     
