@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2022 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -21,6 +21,9 @@ from .Complexity.translations import (
 from .DocStyle.translations import (
     _docStyleMessages, _docStyleMessagesSampleArgs
 )
+from .Imports.translations import (
+    _importsMessages, _importsMessagesSampleArgs
+)
 from .Miscellaneous.translations import (
     _miscellaneousMessages, _miscellaneousMessagesSampleArgs
 )
@@ -503,6 +506,7 @@ messageCatalogs = {
     "C": _complexityMessages,
     "D": _docStyleMessages,
     "E": _pycodestyleErrorMessages,
+    "I": _importsMessages,
     "M": _miscellaneousMessages,
     "N": _namingStyleMessages,
     "P": _pathlibMessages,
@@ -518,6 +522,7 @@ messageSampleArgsCatalog = {
     "C": _complexityMessagesSampleArgs,
     "D": _docStyleMessagesSampleArgs,
     "E": _pycodestyleErrorMessagesSampleArgs,
+    "I": _importsMessagesSampleArgs,
     "M": _miscellaneousMessagesSampleArgs,
     "S": _securityMessagesSampleArgs,
     "W": _pycodestyleWarningMessagesSampleArgs,
