@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2022 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -69,6 +69,7 @@ class ConfigurationMode(enum.Enum):
     TRAYSTARTERMODE = 1
     HEXEDITORMODE = 2
     WEBBROWSERMODE = 3
+    EDITORMODE = 4
 
 
 class ConfigurationWidget(QWidget):
@@ -380,6 +381,68 @@ class ConfigurationWidget(QWidget):
             self.configItems.update(
                 ericApp().getObject("PluginManager").getPluginConfigData())
         
+        elif displayMode == ConfigurationMode.EDITORMODE:
+            self.configItems = {
+                # key : [display string, pixmap name, dialog module name or
+                #        page creation function, parent key,
+                #        reference to configuration page (must always be last)]
+                # The dialog module must have the module function 'create' to
+                # create the configuration page. This must have the method
+                # 'save' to save the settings.
+                "iconsPage":
+                [self.tr("Icons"), "preferences-icons",
+                 "IconsPage", None, None],
+                "interfacePage":
+                [self.tr("Interface"), "preferences-interface",
+                 "InterfaceLightPage", None, None],
+                "printerPage":
+                [self.tr("Printer"), "preferences-printer",
+                 "PrinterPage", None, None],
+                
+                "0editorPage":
+                [self.tr("Editor"), "preferences-editor",
+                 None, None, None],
+                "editorGeneralPage":
+                [self.tr("General"), "preferences-general",
+                 "EditorGeneralPage", "0editorPage", None],
+                "editorFilePage":
+                [self.tr("Filehandling"),
+                 "preferences-filehandling",
+                 "EditorFilePage", "0editorPage", None],
+                "editorSearchPage":
+                [self.tr("Searching"), "preferences-search",
+                 "EditorSearchPage", "0editorPage", None],
+                "editorSpellCheckingPage":
+                [self.tr("Spell checking"),
+                 "preferences-spellchecking",
+                 "EditorSpellCheckingPage", "0editorPage", None],
+                "editorStylesPage":
+                [self.tr("Style"), "preferences-styles",
+                 "EditorStylesPage", "0editorPage", None],
+                "editorTypingPage":
+                [self.tr("Typing"), "preferences-typing",
+                 "EditorTypingPage", "0editorPage", None],
+                
+                "1editorLexerPage":
+                [self.tr("Highlighters"),
+                 "preferences-highlighting-styles",
+                 None, "0editorPage", None],
+                "editorHighlightersPage":
+                [self.tr("Filetype Associations"),
+                 "preferences-highlighter-association",
+                 "EditorHighlightersPage", "1editorLexerPage", None],
+                "editorHighlightingStylesPage":
+                [self.tr("Styles"),
+                 "preferences-highlighting-styles",
+                 "EditorHighlightingStylesPage", "1editorLexerPage", None],
+                "editorKeywordsPage":
+                [self.tr("Keywords"), "preferences-keywords",
+                 "EditorKeywordsPage", "1editorLexerPage", None],
+                "editorPropertiesPage":
+                [self.tr("Properties"), "preferences-properties",
+                 "EditorPropertiesPage", "1editorLexerPage", None],
+            }
+        
         elif displayMode == ConfigurationMode.WEBBROWSERMODE:
             self.configItems = {
                 # key : [display string, pixmap name, dialog module name or
@@ -388,9 +451,12 @@ class ConfigurationWidget(QWidget):
                 # The dialog module must have the module function 'create' to
                 # create the configuration page. This must have the method
                 # 'save' to save the settings.
+                "iconsPage":
+                [self.tr("Icons"), "preferences-icons",
+                 "IconsPage", None, None],
                 "interfacePage":
                 [self.tr("Interface"), "preferences-interface",
-                 "WebBrowserInterfacePage", None, None],
+                 "InterfaceLightPage", None, None],
                 "networkPage":
                 [self.tr("Network"), "preferences-network",
                  "NetworkPage", None, None],
@@ -444,11 +510,34 @@ class ConfigurationWidget(QWidget):
                 # The dialog module must have the module function 'create' to
                 # create the configuration page. This must have the method
                 # 'save' to save the settings.
+                "iconsPage":
+                [self.tr("Icons"), "preferences-icons",
+                 "IconsPage", None, None],
+                "interfacePage":
+                [self.tr("Interface"), "preferences-interface",
+                 "InterfaceLightPage", None, None],
                 "hexEditorPage":
                 [self.tr("Hex Editor"), "hexEditor",
                  "HexEditorPage", None, None],
             }
         
+        else:
+            # display mode for generic use
+            self.configItems = {
+                # key : [display string, pixmap name, dialog module name or
+                #        page creation function, parent key,
+                #        reference to configuration page (must always be last)]
+                # The dialog module must have the module function 'create' to
+                # create the configuration page. This must have the method
+                # 'save' to save the settings.
+                "iconsPage":
+                [self.tr("Icons"), "preferences-icons",
+                 "IconsPage", None, None],
+                "interfacePage":
+                [self.tr("Interface"), "preferences-interface",
+                 "InterfaceLightPage", None, None],
+            }
+        
         # generate the list entries
         self.__expandedEntries = []
         for key in sorted(self.configItems.keys()):
