@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2022 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -76,6 +76,10 @@ class FindFileWidget(QWidget, Ui_FindFileWidget):
         
         self.layout().setContentsMargins(0, 3, 0, 0)
         
+        self.caseToolButton.setIcon(UI.PixmapCache.getIcon("caseSensitive"))
+        self.wordToolButton.setIcon(UI.PixmapCache.getIcon("wholeWord"))
+        self.regexpToolButton.setIcon(UI.PixmapCache.getIcon("regexp"))
+        
         self.dirPicker.setMode(EricPathPickerModes.DIRECTORY_MODE)
         self.dirPicker.setInsertPolicy(QComboBox.InsertPolicy.InsertAtTop)
         self.dirPicker.setSizeAdjustPolicy(
@@ -89,6 +93,10 @@ class FindFileWidget(QWidget, Ui_FindFileWidget):
         self.findButton.clicked.connect(self.__doSearch)
         self.findButton.setIcon(UI.PixmapCache.getIcon("find"))
         
+        self.clearButton.setEnabled(False)
+        self.clearButton.clicked.connect(self.__clearResults)
+        self.clearButton.setIcon(UI.PixmapCache.getIcon("clear"))
+        
         self.replaceButton.setIcon(UI.PixmapCache.getIcon("editReplace"))
         
         self.modeToggleButton.clicked.connect(self.__toggleReplaceMode)
@@ -249,6 +257,8 @@ class FindFileWidget(QWidget, Ui_FindFileWidget):
         
         # change some interface elements and properties
         self.findList.clear()
+        self.clearButton.setEnabled(False)
+        
         if self.__replaceMode:
             self.replaceButton.show()
             self.replaceLabel.show()
@@ -516,9 +526,9 @@ class FindFileWidget(QWidget, Ui_FindFileWidget):
         self.findProgress.setMaximum(len(files))
         
         # retrieve the values
-        reg = self.regexpCheckBox.isChecked()
-        wo = self.wordCheckBox.isChecked()
-        cs = self.caseCheckBox.isChecked()
+        reg = self.regexpToolButton.isChecked()
+        wo = self.wordToolButton.isChecked()
+        cs = self.caseToolButton.isChecked()
         ct = self.findtextCombo.currentText()
         txt = ct if reg else re.escape(ct)
         if wo:
@@ -576,6 +586,7 @@ class FindFileWidget(QWidget, Ui_FindFileWidget):
         # set the button states
         self.stopButton.setEnabled(True)
         self.findButton.setEnabled(False)
+        self.clearButton.setEnabled(False)
         
         # now go through all the files
         self.__populating = True
@@ -588,8 +599,6 @@ class FindFileWidget(QWidget, Ui_FindFileWidget):
             if self.__cancelSearch:
                 break
             
-            self.findProgressLabel.setPath(file)
-            
             fn = (
                 os.path.join(self.project.getProjectPath(), file)
                 if self.projectButton.isChecked() else
@@ -655,6 +664,18 @@ class FindFileWidget(QWidget, Ui_FindFileWidget):
         
         self.stopButton.setEnabled(False)
         self.findButton.setEnabled(True)
+        self.clearButton.setEnabled(self.findList.topLevelItemCount() != 0)
+    
+    @pyqtSlot()
+    def __clearResults(self):
+        """
+        Private slot to clear the current search results.
+        """
+        self.findList.clear()
+        self.replaceButton.setEnabled(False)
+        self.clearButton.setEnabled(False)
+        self.findProgressLabel.setPath("")
+        self.findProgress.setValue(0)
     
     @pyqtSlot(QTreeWidgetItem, int)
     def on_findList_itemDoubleClicked(self, itm, column):
@@ -767,8 +788,6 @@ class FindFileWidget(QWidget, Ui_FindFileWidget):
                 file = itm.text(0)
                 origHash = itm.data(0, self.md5Role)
                 
-                self.findProgressLabel.setPath(file)
-                
                 if self.projectButton.isChecked():
                     fn = os.path.join(self.project.getProjectPath(), file)
                 else:
@@ -836,6 +855,7 @@ class FindFileWidget(QWidget, Ui_FindFileWidget):
         self.findList.clear()
         self.replaceButton.setEnabled(False)
         self.findButton.setEnabled(True)
+        self.clearButton.setEnabled(False)
     
     @pyqtSlot(QPoint)
     def __contextMenuRequested(self, pos):
