@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2022 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -1129,14 +1129,22 @@ def direntries(path, filesonly=False, pattern=None, followsymlinks=True,
     Function returning a list of all files and directories.
     
     @param path root of the tree to check
+    @type str
     @param filesonly flag indicating that only files are wanted
-    @param pattern a filename pattern to check against
+    @type bool
+    @param pattern a filename pattern or list of filename patterns to check
+        against
+    @type str or list of str
     @param followsymlinks flag indicating whether symbolic links
-            should be followed
+        should be followed
+    @type bool
     @param checkStop function to be called to check for a stop
+    @type function
     @return list of all files and directories in the tree rooted
         at path. The names are expanded to start with path.
+    @rtype list of strs
     """
+    patterns = pattern if isinstance(pattern, list) else [pattern]
     files = [] if filesonly else [path]
     try:
         entries = os.listdir(path)
@@ -1148,14 +1156,15 @@ def direntries(path, filesonly=False, pattern=None, followsymlinks=True,
                          '.hg',
                          '.git',
                          '.ropeproject',
-                         '.eric7project']:
+                         '.eric7project',
+                         '.jedi']:
                 continue
             
             fentry = os.path.join(path, entry)
             if (
                 pattern and
                 not os.path.isdir(fentry) and
-                not fnmatch.fnmatch(entry, pattern)
+                not any(fnmatch.fnmatch(entry, p) for p in patterns)
             ):
                 # entry doesn't fit the given pattern
                 continue
