@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2022 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -16,6 +16,7 @@ from PyQt6.QtCore import pyqtSlot, QProcess, QTimer
 from PyQt6.QtWidgets import QDialog, QDialogButtonBox
 
 from EricWidgets.EricPathPicker import EricPathPickerModes
+from EricWidgets.EricApplication import ericApp
 
 from .Ui_VirtualenvConfigurationDialog import Ui_VirtualenvConfigurationDialog
 
@@ -94,7 +95,11 @@ class VirtualenvConfigurationDialog(QDialog, Ui_VirtualenvConfigurationDialog):
         self.buttonBox.button(
             QDialogButtonBox.StandardButton.Ok).setEnabled(False)
         
-        self.__mandatoryStyleSheet = "QLineEdit {border: 2px solid;}"
+        self.__mandatoryStyleSheet = (
+            "QLineEdit {border: 2px solid; border-color: #dd8888}"
+            if ericApp().usesDarkPalette() else
+            "QLineEdit {border: 2px solid; border-color: #800000}"
+        )
         self.targetDirectoryPicker.setStyleSheet(self.__mandatoryStyleSheet)
         self.nameEdit.setStyleSheet(self.__mandatoryStyleSheet)
         self.condaTargetDirectoryPicker.setStyleSheet(
