@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2016 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2016 - 2022 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -580,7 +580,7 @@ class TabManagerWidget(QWidget):
         if isinstance(icon, EricClickableLabel):
             window = icon.window()
         elif isinstance(icon, QAction):
-            window = icon.parentWidget()
+            window = icon.parent()
         
         if window is not None:
             titleBarHeight = self.style().pixelMetric(
@@ -588,10 +588,9 @@ class TabManagerWidget(QWidget):
             
             y = max(0, window.frameGeometry().top() + titleBarHeight + 1)
             
-            desktop = ericApp().desktop()
-            desktopGeometry = desktop.availableGeometry(self)
+            availableGeometry = ericApp().primaryScreen().availableGeometry()
             windowFrameGeometry = window.frameGeometry()
-            if (desktopGeometry.width() - windowFrameGeometry.right() - 1 >
+            if (availableGeometry.width() - windowFrameGeometry.right() - 1 >
                     self.frameGeometry().width()):
                 x = windowFrameGeometry.right() + 1
             else:
